@@ -23,15 +23,19 @@
 #include <QtCore/QString>
 #include <kcoreaddons_export.h>
 
+/**
+ * @namespace KFileSystemType
+ * Provides utility functions for the type of file systems.
+ */
 namespace KFileSystemType
 {
 enum Type {
     Unknown,
-    Nfs, // NFS or other full-featured networked filesystems (autofs, subfs, cachefs, sshfs)
-    Smb, // SMB/CIFS mount (networked but with some FAT-like behavior)
-    Fat,  // FAT or similar (msdos, fat, vfat)
-    Ramfs,  // RAMDISK mount
-    Other // ext, reiser, and so on. "Normal" local filesystems.
+    Nfs, ///< NFS or other full-featured networked filesystems (autofs, subfs, cachefs, sshfs)
+    Smb, ///< SMB/CIFS mount (networked but with some FAT-like behavior)
+    Fat,  ///< FAT or similar (msdos, fat, vfat)
+    Ramfs,  ///< RAMDISK mount
+    Other ///< ext, reiser, and so on. "Normal" local filesystems.
 };
 
 /**
